# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class PredictionDTO(BaseModel):
    """
    A prediction is a forecast of future events with advanced machine learning models.
    """ # noqa: E501
    data_end_date: Optional[StrictStr] = Field(default=None, description="The date from which data is no longer available for this prediction.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataEndDate")
    data_start_date: Optional[StrictStr] = Field(default=None, description="The date from which data becomes available for this prediction.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataStartDate")
    description: Optional[StrictStr] = Field(default=None, description="The localized description of the prediction.")
    display_name: Optional[StrictStr] = Field(default=None, description="The localized display name of the prediction.", alias="displayName")
    event: Optional[StrictStr] = Field(default=None, description="The object name of the event to predict. The prediction's training data uses past occurrences of the event to  make predictions. For example, the Predicted Risk of Resignation model uses the Employee_Exit event to estimate  likelihood of exit from the organization.")
    event_filter: Optional[StrictStr] = Field(default=None, description="The object name of a selection concept to filter event occurrences in the prediction's training data.", alias="eventFilter")
    factor_concepts: Optional[List[StrictStr]] = Field(default=None, description="The list of unique IDs of the concepts used as prediction factors.", alias="factorConcepts")
    factor_dimensions: Optional[List[StrictStr]] = Field(default=None, description="The list of unique IDs of the dimensions used as prediction factors.", alias="factorDimensions")
    factor_properties: Optional[List[StrictStr]] = Field(default=None, description="The list of unique IDs of the properties used as prediction factors.  Note: Factors are conditions used as part of a Visier prediction. For example, Compensation might be a factor in  predicting an individual's risk of resignation. Factors are chosen based on:  - Availability in tenants.  - Prediction impact, such as salary.  - Reducing bias.", alias="factorProperties")
    factors_name: Optional[StrictStr] = Field(default=None, description="The unique name of the factor property. The prediction's formula references the factor property as an object. This is automatically generated.", alias="factorsName")
    id: Optional[StrictStr] = Field(default=None, description="The unique ID of the prediction.  Note: See `Predictions` to get the ID.")
    is_multi_tenant: Optional[StrictBool] = Field(default=None, description="If `true`, this prediction applies to more than one tenant. If \"false\", the prediction only applies to the current tenant.", alias="isMultiTenant")
    label_property: Optional[StrictStr] = Field(default=None, description="The unique ID of the property label for the prediction. This is automatically generated.", alias="labelProperty")
    minimum_training_months: Optional[StrictStr] = Field(default=None, description="The minimum amount of time, in months, to train the prediction model.", alias="minimumTrainingMonths")
    score_name: Optional[StrictStr] = Field(default=None, description="The unique name of the score property.  The prediction's formula references the score property as an object. This is automatically generated.", alias="scoreName")
    subject: Optional[StrictStr] = Field(default=None, description="The object name of the subject that the prediction applies to. For example, Employee.")
    subject_filter: Optional[StrictStr] = Field(default=None, description="The object name of a selection concept to filter the subject population. Filtering the population selects  specific subject members in the prediction's training data. For example, using the isHighPerformer concept will  filter the prediction to only high performing employees.", alias="subjectFilter")
    subject_key: Optional[StrictStr] = Field(default=None, description="The unique ID of the subject's property that the prediction applies to. For example, Employee.EmployeeID.", alias="subjectKey")
    subject_parent_key: Optional[StrictStr] = Field(default=None, description="The unique ID of the reference that connects a subject member to other members. For example, Employee.Direct_Manager.  Note: The `subjectParentKey` defines parent, child, and peer relationships between subject members.", alias="subjectParentKey")
    __properties: ClassVar[List[str]] = ["dataEndDate", "dataStartDate", "description", "displayName", "event", "eventFilter", "factorConcepts", "factorDimensions", "factorProperties", "factorsName", "id", "isMultiTenant", "labelProperty", "minimumTrainingMonths", "scoreName", "subject", "subjectFilter", "subjectKey", "subjectParentKey"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PredictionDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PredictionDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "dataEndDate": obj.get("dataEndDate"),
            "dataStartDate": obj.get("dataStartDate"),
            "description": obj.get("description"),
            "displayName": obj.get("displayName"),
            "event": obj.get("event"),
            "eventFilter": obj.get("eventFilter"),
            "factorConcepts": obj.get("factorConcepts"),
            "factorDimensions": obj.get("factorDimensions"),
            "factorProperties": obj.get("factorProperties"),
            "factorsName": obj.get("factorsName"),
            "id": obj.get("id"),
            "isMultiTenant": obj.get("isMultiTenant"),
            "labelProperty": obj.get("labelProperty"),
            "minimumTrainingMonths": obj.get("minimumTrainingMonths"),
            "scoreName": obj.get("scoreName"),
            "subject": obj.get("subject"),
            "subjectFilter": obj.get("subjectFilter"),
            "subjectKey": obj.get("subjectKey"),
            "subjectParentKey": obj.get("subjectParentKey")
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_analytic_model.models.parameter_definition_dto import ParameterDefinitionDTO
from typing import Optional, Set
from typing_extensions import Self

class MetricDTO(BaseModel):
    """
    A metric is a calculation based on one or more attribute values of analytic objects.
    """ # noqa: E501
    analytic_object_id: Optional[StrictStr] = Field(default=None, description="The unique ID of the analytic object.", alias="analyticObjectId")
    category: Optional[StrictStr] = Field(default=None, description="The category of the metric. Will be one of: `REGULAR`, `DERIVED` or `PLANNING`.")
    data_end_date: Optional[StrictStr] = Field(default=None, description="The date from which data is no longer available for this metric.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataEndDate")
    data_start_date: Optional[StrictStr] = Field(default=None, description="The date from which data becomes available for this metric.  Note: Format is the number of milliseconds since midnight 01 January, 1970 UTC as a string.  Epochs are expressed as 64-bit integers and represented as stringified longs in JSON due to JSON's inherent  limitation in representing large numbers.", alias="dataStartDate")
    description: Optional[StrictStr] = Field(default=None, description="The localized description of the metric.")
    display_name: Optional[StrictStr] = Field(default=None, description="The localized display name of the metric.", alias="displayName")
    id: Optional[StrictStr] = Field(default=None, description="The unique ID of the metric. Note: See `Metrics` to get the ID.")
    parameters: Optional[List[ParameterDefinitionDTO]] = Field(default=None, description="The collection of parameters defined for the metric.")
    visible_in_app: Optional[StrictBool] = Field(default=None, description="// `true` if this metric is set to be visible in your solution.", alias="visibleInApp")
    __properties: ClassVar[List[str]] = ["analyticObjectId", "category", "dataEndDate", "dataStartDate", "description", "displayName", "id", "parameters", "visibleInApp"]

    @field_validator('category')
    def category_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['REGULAR', 'DERIVED', 'PLANNING']):
            raise ValueError("must be one of enum values ('REGULAR', 'DERIVED', 'PLANNING')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MetricDTO from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in parameters (list)
        _items = []
        if self.parameters:
            for _item_parameters in self.parameters:
                if _item_parameters:
                    _items.append(_item_parameters.to_dict())
            _dict['parameters'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MetricDTO from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "analyticObjectId": obj.get("analyticObjectId"),
            "category": obj.get("category"),
            "dataEndDate": obj.get("dataEndDate"),
            "dataStartDate": obj.get("dataStartDate"),
            "description": obj.get("description"),
            "displayName": obj.get("displayName"),
            "id": obj.get("id"),
            "parameters": [ParameterDefinitionDTO.from_dict(_item) for _item in obj["parameters"]] if obj.get("parameters") is not None else None,
            "visibleInApp": obj.get("visibleInApp")
        })
        return _obj





# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_analytic_model.api.object_configuration_api import ObjectConfigurationApi


class TestObjectConfigurationApi(unittest.TestCase):
    """ObjectConfigurationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ObjectConfigurationApi()

    def tearDown(self) -> None:
        pass

    def test_get_calculation_concept(self) -> None:
        """Test case for get_calculation_concept

        Retrieve the configuration of a calculation concept
        """
        pass

    def test_get_calculation_concepts(self) -> None:
        """Test case for get_calculation_concepts

        Retrieve all calculation concepts
        """
        pass

    def test_get_selection_concept(self) -> None:
        """Test case for get_selection_concept

        Retrieve the configuration of a selection concept
        """
        pass

    def test_get_selection_concepts(self) -> None:
        """Test case for get_selection_concepts

        Retrieve all selection concepts
        """
        pass

    def test_map_calculation_concept(self) -> None:
        """Test case for map_calculation_concept

        Map dimension members to nodes in a calculation concept
        """
        pass

    def test_map_selection_concept(self) -> None:
        """Test case for map_selection_concept

        Map dimension members to a selection concept
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


# import models into model package
from visier_api_analytic_model.models.aggregation_type_option_dto import AggregationTypeOptionDTO
from visier_api_analytic_model.models.aggregation_type_parameter_dto import AggregationTypeParameterDTO
from visier_api_analytic_model.models.analytic_object_dto import AnalyticObjectDTO
from visier_api_analytic_model.models.analytic_object_filter_dto import AnalyticObjectFilterDTO
from visier_api_analytic_model.models.analytic_objects_dto import AnalyticObjectsDTO
from visier_api_analytic_model.models.calculation_concept_configuration_dto import CalculationConceptConfigurationDTO
from visier_api_analytic_model.models.calculation_concept_configuration_map_dto import CalculationConceptConfigurationMapDTO
from visier_api_analytic_model.models.calculation_concept_dto import CalculationConceptDTO
from visier_api_analytic_model.models.calculation_concept_list_dto import CalculationConceptListDTO
from visier_api_analytic_model.models.concept_configuration_result_dto import ConceptConfigurationResultDTO
from visier_api_analytic_model.models.currencies_dto import CurrenciesDTO
from visier_api_analytic_model.models.currency_dto import CurrencyDTO
from visier_api_analytic_model.models.currency_rate_dto import CurrencyRateDTO
from visier_api_analytic_model.models.currency_rates_dto import CurrencyRatesDTO
from visier_api_analytic_model.models.dimension_dto import DimensionDTO
from visier_api_analytic_model.models.dimension_filter_dto import DimensionFilterDTO
from visier_api_analytic_model.models.dimension_mapping_validation_dto import DimensionMappingValidationDTO
from visier_api_analytic_model.models.dimension_mapping_validation_execution_dto import DimensionMappingValidationExecutionDTO
from visier_api_analytic_model.models.dimension_member_dto import DimensionMemberDTO
from visier_api_analytic_model.models.dimension_member_reference_dto import DimensionMemberReferenceDTO
from visier_api_analytic_model.models.dimension_reference_dto import DimensionReferenceDTO
from visier_api_analytic_model.models.dimensions_dto import DimensionsDTO
from visier_api_analytic_model.models.google_protobuf_any import GoogleProtobufAny
from visier_api_analytic_model.models.level_dto import LevelDTO
from visier_api_analytic_model.models.member_dto import MemberDTO
from visier_api_analytic_model.models.member_parameter_definition_dto import MemberParameterDefinitionDTO
from visier_api_analytic_model.models.member_values_dto import MemberValuesDTO
from visier_api_analytic_model.models.members_dto import MembersDTO
from visier_api_analytic_model.models.metric_dto import MetricDTO
from visier_api_analytic_model.models.metrics_dto import MetricsDTO
from visier_api_analytic_model.models.numeric_parameter_definition_dto import NumericParameterDefinitionDTO
from visier_api_analytic_model.models.object_reference_dto import ObjectReferenceDTO
from visier_api_analytic_model.models.parameter_definition_dto import ParameterDefinitionDTO
from visier_api_analytic_model.models.perspective_configuration_dto import PerspectiveConfigurationDTO
from visier_api_analytic_model.models.perspective_node_dto import PerspectiveNodeDTO
from visier_api_analytic_model.models.plan_parameter_definition_dto import PlanParameterDefinitionDTO
from visier_api_analytic_model.models.planning_concept_filter_context_dto import PlanningConceptFilterContextDTO
from visier_api_analytic_model.models.planning_hierarchy_filter_context_dto import PlanningHierarchyFilterContextDTO
from visier_api_analytic_model.models.planning_model_dto import PlanningModelDTO
from visier_api_analytic_model.models.planning_models_dto import PlanningModelsDTO
from visier_api_analytic_model.models.planning_plan_context_dto import PlanningPlanContextDTO
from visier_api_analytic_model.models.planning_plan_dto import PlanningPlanDTO
from visier_api_analytic_model.models.planning_plans_dto import PlanningPlansDTO
from visier_api_analytic_model.models.population_configuration_dto import PopulationConfigurationDTO
from visier_api_analytic_model.models.prediction_dto import PredictionDTO
from visier_api_analytic_model.models.predictions_dto import PredictionsDTO
from visier_api_analytic_model.models.properties_dto import PropertiesDTO
from visier_api_analytic_model.models.property_dto import PropertyDTO
from visier_api_analytic_model.models.property_reference_dto import PropertyReferenceDTO
from visier_api_analytic_model.models.scenario_or_snapshot_dto import ScenarioOrSnapshotDTO
from visier_api_analytic_model.models.selection_concept_configuration_map_dto import SelectionConceptConfigurationMapDTO
from visier_api_analytic_model.models.selection_concept_dto import SelectionConceptDTO
from visier_api_analytic_model.models.selection_concept_list_dto import SelectionConceptListDTO
from visier_api_analytic_model.models.selection_concepts_dto import SelectionConceptsDTO
from visier_api_analytic_model.models.status import Status
from visier_api_analytic_model.models.tag_map_element_dto import TagMapElementDTO
from visier_api_analytic_model.models.validity_range_dto import ValidityRangeDTO
